#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé le Wed Nov 22 20:02:59 2023

@auteur: david ALBERTO
(www.astrolabe-science.fr)
"""
import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import matplotlib as mpl # Normalisation des valeurs
from PIL import Image

from matplotlib.cbook import get_sample_data

plt.rcParams["font.family"] = "Roboto"

filtre = 1e-3
# filtre = 0
epaisseur = 0.5
xmin, xmax = 400, 750

coord = pd.read_csv("donnees_elements_chimiques.csv", sep='\t')
symboles = coord.symbole
lignes = coord.lig
colonnes = coord.col

liste_symboles = [
    # 'H',
   # 'He',
  # 'Li',
   # 'Cr',
  # 'B',
  # 'C',
  # 'N',
  # 'O',
  # 'F',
  # 'Ne',
  # 'Na',
  # 'Mg',
  # 'Al',
  # 'Si',
  # 'P',
  # 'S',
  # 'Cl',
  # 'Ar',
  'Na'
 ]

def coordonnees(symbole):
    """
    renvoie les coordonnées (tuple) d'un élément de symbole donné.
    """
    x = coord.loc[coord.symbole == symbole, 'col'].values[0]
    y = coord.loc[coord.symbole == symbole, 'lig'].values[0]
    return x, y

def filtrage(data):
    tab = data.replace('"','', regex=True)
    tab = tab.replace('=','', regex=True)
    tab.int = pd.to_numeric(tab['int'], errors='coerce')
    tab.wl = pd.to_numeric(tab['wl'], errors='coerce')
    # print(tab[250:350])
    tab = tab.loc[(tab.wl >= xmin) & (tab.wl <=xmax)]
    # print(np.max(tab.int))
    tab = tab.loc[tab['int'] >= filtre * np.max(tab.int)]
    return tab

def trace(data,axe, symb):
    axe.set_facecolor('black')
    axe.set_xlim(xmin, xmax)
    for L in data.wl:
        axe.axvline(L, lw = epaisseur, color = cmap(norm(L)))
    axe.text(0.01,0.01,symb,transform = axe.transAxes, fontsize=20, c = 'white')

cmap=plt.get_cmap('turbo') # gamme de couleurs du visible
norm = mpl.colors.Normalize(vmin=400,vmax=750)

# fig = plt.figure(figsize=(29.7 / 2.54, 21 / 2.54), tight_layout=True)
fig, axes = plt.subplots()

for symb in liste_symboles:
    x, y = coordonnees(symb)
    # axe = axe
    df = pd.read_csv(symb + '.csv', sep = ',', usecols=[2, 4], names=['wl', 'int'], skiprows=1)
    # print(len(df))
    # print(df[20:50])
    df = filtrage(df)
    # print(len(df))
    trace(df, axes, symb)

img = np.asarray(Image.open('by-nc-sa.png'))
im = plt.imread('by-nc-sa.png')
imgplot = axes.imshow(im, zorder=2)




